From ff25c3327914069f1dc3be6337c8ceb2d0e4f791 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Thu, 12 Apr 2018 09:04:13 +0800
Subject: [PATCH] org-capture: Add a custom to control save target file or not.

* lisp/org-capture.el (org-capture-finalize-save-buffer): New variable.
(org-capture-finalize): Use org-capture-finalize-save-buffer.

I use org-capture to capture text to a file of my mobile phone
with the help of tramp and termux's sshd, the save buffer is very
slow, so I want to org-capture-finalize just update buffer, and
I save buffer manually when need.
---
 lisp/org-capture.el | 11 ++++++++++-
 1 file changed, 10 insertions(+), 1 deletion(-)

diff --git a/lisp/org-capture.el b/lisp/org-capture.el
index f59e2ce6a..e2234e816 100644
--- a/lisp/org-capture.el
+++ b/lisp/org-capture.el
@@ -438,6 +438,12 @@ The capture buffer is current and still narrowed."
   :version "24.1"
   :type 'hook)
 
+(defcustom org-capture-finalize-save-buffer t
+  "When nil, org-capture-finalize will not save target file's buffer."
+  :group 'org-capture
+  :version "24.1"
+  :type 'boolean)
+
 (defcustom org-capture-bookmark t
   "When non-nil, add a bookmark pointing at the last stored
 position when capturing."
@@ -791,7 +797,10 @@ captured item after finalizing."
 	(org-encrypt-entry)))
 
     ;; Kill the indirect buffer
-    (save-buffer)
+    (if org-capture-finalize-save-buffer
+	(save-buffer)
+      (message "The capture target file is not auto saved, please save it manually."))
+
     (let ((return-wconf (org-capture-get :return-to-wconf 'local))
 	  (new-buffer (org-capture-get :new-buffer 'local))
 	  (kill-buffer (org-capture-get :kill-buffer 'local))
-- 
2.16.2

